@@ -3,9 +3,9 @@ from typing import TYPE_CHECKING, Iterable, Hashable, Union, SupportsInt, Mappin
 from pathlib import Path
 import numpy as np
 from numpy.typing import DTypeLike
-from ..axesmixin import AxesMixin, get_axes_tuple
+from ..axesmixin import AxesMixin
 from ..._types import *
-from ...axes import ImageAxesError, Slicer, AxesLike, Axes
+from ...axes import ImageAxesError, AxesLike, Axes
 from ...array_api import xp
 from ...utils import axesop, slicer
 from ...collections import DataList
@@ -80,12 +80,23 @@ class MetaArray(AxesMixin, np.ndarray):
     def metadata(self) -> dict[str, Any]:
         """Metadata dictionary of the array."""
         return self._metadata
+
+    @metadata.setter
+    def metadata(self, value):
+        if not isinstance(value, dict):
+            raise TypeError(f"Cannot set {type(value)} as a metadata.")
+        self._metadata = value
     
     @property
     def value(self) -> np.ndarray:
         """Numpy view of the array."""
         return np.asarray(self)
     
+    def __repr__(self) -> str:
+        if self.ndim > 0:
+            return super().__repr__()
+        return self.value[()]
+
     def _repr_dict_(self) -> dict[str, Any]:
         return {
             "name": self.name,
@@ -100,33 +111,7 @@ class MetaArray(AxesMixin, np.ndarray):
     
     @property
     def shape(self):
-        try:
-            tup = get_axes_tuple(self)
-            return tup(*super().shape)
-        except ImageAxesError:
-            return super().shape
-    
-    
-    def _set_additional_props(self, other):
-        # set additional properties
-        # If `other` does not have it and `self` has, then the property will be inherited.
-        for p in self.__class__.additional_props:
-            setattr(self, p, getattr(other, p, 
-                                     getattr(self, p, 
-                                             None)))
-    
-    def _set_info(self, other: Self, new_axes: Any= AxesMixin._INHERIT):
-        self._set_additional_props(other)
-        # set axes
-        try:
-            if new_axes is not self._INHERIT:
-                self.axes = new_axes
-            else:
-                self.axes = other.axes.copy()
-        except ImageAxesError:
-            self.axes = None
-        
-        return None
+        return self.axes.tuple(super().shape)
     
     def __getitem__(self, key: SupportSlicing) -> Self:
         key = slicer.solve_slicer(key, self.axes)
@@ -138,17 +123,10 @@ class MetaArray(AxesMixin, np.ndarray):
         
         if isinstance(out, self.__class__):  # cannot set attribution to such as numpy.int32 
             new_axes = axesop.slice_axes(self.axes, key)
-
-            out._getitem_additional_set_info(
-                self, new_axes=new_axes, key=key
-            )
+            out._getitem_additional_set_info(self, new_axes=new_axes, key=key)
 
         return out
     
-    def _getitem_additional_set_info(self, other: Self, **kwargs):
-        self._set_info(other, kwargs["new_axes"])
-        return None
-    
     def __setitem__(self, key: SupportSlicing, value):
         key = slicer.solve_slicer(key, self.axes)
         
@@ -161,6 +139,35 @@ class MetaArray(AxesMixin, np.ndarray):
 
         super().__setitem__(key, value)
     
+    def sel(self, indexer=None, /, **kwargs: dict[str, Any]) -> Self:
+        """."""
+        if indexer is not None:
+            kwargs.update(indexer)
+        axes = self.axes
+        slices = [slice(None)] * self.ndim
+        for k, v in kwargs.items():
+            idx = axes.find(k)
+            axis = axes[idx]
+            if lbl := axis.labels:
+                if isinstance(v, list):
+                    slices[idx] = [lbl.index(each) for each in v]
+                else:
+                    slices[idx] = lbl.get_slice(v)
+            else:
+                raise ValueError(f"Cannot select {k} because it has no labels.")
+        return self[tuple(slices)]
+    
+    def isel(self, indexer=None, /, **kwargs: dict[str, Any]) -> Self:
+        if indexer is not None:
+            kwargs.update(indexer)
+
+        key = slicer.solve_slicer(kwargs, self.axes)
+        out = super().__getitem__(key)  # get item as np.ndarray
+        
+        if isinstance(out, self.__class__):  # cannot set attribution to such as numpy.int32 
+            new_axes = axesop.slice_axes(self.axes, key)
+            out._getitem_additional_set_info(self, new_axes=new_axes, key=key)
+        return out
     
     def __array_finalize__(self, obj):
         """
@@ -200,19 +207,6 @@ class MetaArray(AxesMixin, np.ndarray):
         result._process_output(ufunc, args, kwargs)
         return result
     
-    def _inherit_meta(self, obj: AxesMixin, ufunc, **kwargs):
-        """
-        Copy axis etc. from obj.
-        This is called in __array_ufunc__(). Unlike _set_info(), keyword `axis` must be
-        considered because it changes `ndim`.
-        """
-        if "axis" in kwargs.keys():
-            new_axes = obj.axes.drop(kwargs["axis"])
-        else:
-            new_axes = self._INHERIT
-        self._set_info(obj, new_axes=new_axes)
-        return self
-    
     def __array_function__(self, func, types, args, kwargs):
         """
         Every time a numpy function (np.mean...) is called, this function will be called. Essentially numpy
@@ -242,21 +236,7 @@ class MetaArray(AxesMixin, np.ndarray):
                 result._process_output(func, args, kwargs)
         
         return result
-    
-    def _process_output(self, func, args, kwargs):
-        # find the largest MetaArray. Largest because of broadcasting.
-        arr = None
-        for arg in args:
-            if isinstance(arg, self.__class__):
-                if arr is None or arr.ndim < arg.ndim:
-                    arr = arg
-                    
-        if isinstance(arr, self.__class__):
-            self._inherit_meta(arr, func, **kwargs)
-        
-        return self
-        
-    
+
     @classmethod
     def implements(cls, numpy_function):
         """
@@ -293,11 +273,7 @@ class MetaArray(AxesMixin, np.ndarray):
             Argmax of the array.
         """
         argmax = np.unravel_index(np.argmax(self), self.shape)
-        try:
-            tup = get_axes_tuple(self)
-            return tup(*argmax)
-        except ImageAxesError:
-            return argmax
+        return self.axes.tuple(argmax)
     
     def split(self, axis=None) -> DataList[Self]:
         """
@@ -426,7 +402,7 @@ class MetaArray(AxesMixin, np.ndarray):
                 **kwargs
             )
             
-            out = out.compute()
+            out = xp.asnumpy(out.compute())
             
         out = out.view(self.__class__)
         
@@ -526,7 +502,16 @@ class MetaArray(AxesMixin, np.ndarray):
             new_axes = axes
         out._set_info(self, new_axes=new_axes)
         return out
-    
+
+    def _dimension_matches(self, array: MetaArray):
+        """Check if dimension satisfies ``self <: array``."""
+        img_shape = array.shape
+        label_shape = self.shape
+        return all(
+            [getattr(img_shape, str(a), _NOTME) == getattr(label_shape, str(a), _NOTME)
+            for a in self.axes]
+        )
+        
     def __add__(self, value) -> Self:
         value = self._broadcast(value)
         return super().__add__(value)
@@ -610,7 +595,62 @@ class MetaArray(AxesMixin, np.ndarray):
     def __ifloordiv__(self, value) -> Self:
         value = self._broadcast(value)
         return super().__ifloordiv__(value)
+    
+    
+    def _set_additional_props(self, other):
+        # set additional properties
+        # If `other` does not have it and `self` has, then the property will be inherited.
+        for p in self.__class__.additional_props:
+            setattr(self, p, getattr(other, p, 
+                                     getattr(self, p, 
+                                             None)))
+    
+    def _set_info(self, other: Self, new_axes: Any= AxesMixin._INHERIT):
+        self._set_additional_props(other)
+        # set axes
+        try:
+            if new_axes is not self._INHERIT:
+                self.axes = new_axes
+            else:
+                self.axes = other.axes.copy()
+        except ImageAxesError:
+            self.axes = None
+        
+        return None
+    
+    def _process_output(self, func, args, kwargs):
+        # find the largest MetaArray. Largest because of broadcasting.
+        arr = None
+        for arg in args:
+            if isinstance(arg, self.__class__):
+                if arr is None or arr.ndim < arg.ndim:
+                    arr = arg
+                    
+        if isinstance(arr, self.__class__):
+            self._inherit_meta(arr, func, **kwargs)
+        
+        return self
+    
+    def _getitem_additional_set_info(self, other: Self, key: Slices, new_axes):
+        return self._set_info(other, new_axes=new_axes)
+    
+    def _inherit_meta(self, obj: AxesMixin, ufunc, **kwargs):
+        """
+        Copy axis etc. from obj.
+        This is called in __array_ufunc__(). Unlike _set_info(), keyword `axis` must be
+        considered because it changes `ndim`.
+        """
+        if "axis" in kwargs.keys():
+            new_axes = obj.axes.drop(kwargs["axis"])
+        else:
+            new_axes = self._INHERIT
+        self._set_info(obj, new_axes=new_axes)
+        return self
 
+    if TYPE_CHECKING:
+        def astype(self, dtype) -> Self: ...
+        def flatten(self, order="C") -> Self: ...
+        def ravel(self, order="C") -> Self: ...
 
 def _list_of_axes(img: MetaArray, axis):
     if axis is None:
@@ -640,3 +680,10 @@ def _replace_inputs(img: MetaArray, args: tuple[Any], kwargs: dict[str, Any]):
         kwargs["out"] = tuple(_as_np_ndarray(a) for a in kwargs["out"])
     
     return args, kwargs
+
+
+class NotMe:
+    def __eq__(self, other):
+        return False
+
+_NOTME = NotMe()
