@@ -11,7 +11,7 @@ import tempfile
 
 from .labeledarray import LabeledArray
 from .imgarray import ImgArray
-from .axesmixin import AxesMixin, get_axes_tuple
+from .axesmixin import AxesMixin
 from ._utils._skimage import skres
 from ._utils import _misc, _transform, _structures, _filters, _deconv, _corr, _docs
 
@@ -87,12 +87,8 @@ class LazyImgArray(AxesMixin):
     
     @property
     def shape(self):
-        try:
-            tup = get_axes_tuple(self)
-            return tup(*self.value.shape)
-        except ImageAxesError:
-            return self.value.shape
-    
+        return self.axes.tuple(self.value.shape)
+        
     @property
     def dtype(self):
         return self.value.dtype
@@ -107,11 +103,7 @@ class LazyImgArray(AxesMixin):
     
     @property
     def chunksize(self):
-        try:
-            tup = get_axes_tuple(self)
-            return tup(*self.value.chunksize)
-        except ImageAxesError:
-            return self.value.chunksize
+        return self.axes.tuple(self.value.chunksize)
         
     @property
     def GB(self) -> float:
@@ -304,19 +296,32 @@ class LazyImgArray(AxesMixin):
         return out
     
     @_docs.copy_docs(LabeledArray.imsave)
-    def imsave(self, save_path: str, dtype = None):
-        save_path = str(save_path)
-        _, ext = os.path.splitext(save_path)
-        
-        if ext == "":
+    def imsave(self, save_path: str | Path, *, dtype = None, overwrite: bool = True):
+        save_path = Path(save_path)
+        if self.ndim < 2:
+            raise ValueError("Cannot save <2D array as an image.")
+
+        if save_path.suffix == "":
             if self.source is not None:
                 ext = self.source.suffix
+                if ext == "":
+                    ext = ".tif"
             else:
                 ext = ".tif"
-            save_path += ext
+            save_path = save_path.parent / (save_path.name + ext)
         
-        if os.sep not in save_path:
-            save_path = os.path.join(self.source.parent, save_path)
+        if not Path(save_path).is_absolute():
+            if self.source is None:
+                raise ValueError(
+                    "Image directory path is unknown. Set by \n"
+                    " >>> img.source = \"...\"\n"
+                    "or specify absolute path like\n"
+                    " >>> img.imsave(\"/path/to/XXX.tif\")"
+                    )
+            save_path = self.source.parent / save_path
+        
+        if not overwrite and save_path.exists():
+            raise FileExistsError(f"File {save_path!r} already exists.")
         if dtype is None:
             dtype = self.dtype
         
@@ -832,7 +837,10 @@ class LazyImgArray(AxesMixin):
                 shear=shear, translation=translation,
                 ndim=len(dims)
             )
-        from dask_image.ndinterp import affine_transform
+        import warnings
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            from dask_image.ndinterp import affine_transform
         return self._apply_dask_filter(
             affine_transform,
             c_axes=complement_axes(dims, self.axes),
@@ -1039,18 +1047,23 @@ class LazyImgArray(AxesMixin):
 
         # I don't know the reason why but output dask array's chunk size along t-axis should be 
         # specified to be 1, and rechunk it map_overlap. 
-        result = da.map_overlap(pcc, img_fft, 
-                                depth={0: (1, 0)}, 
-                                trim=False,
-                                boundary="none",
-                                chunks=(1, ndim) + (1,)*(ndim-1),
-                                meta=np.array([], dtype=np.float32)
-                                )
+        result = da.map_overlap(
+            pcc,
+            img_fft, 
+            depth={0: (1, 0)}, 
+            trim=False,
+            boundary="none",
+            chunks=(1, ndim) + (1,)*(ndim-1),
+            meta=np.array([], dtype=np.float32)
+        )
         
         # For cupy, we must call map_blocks (or from_delayed and delayed) here.
-        result = da.map_blocks(np.cumsum, result[..., 0].rechunk((len_t, ndim)), 
-                               axis=0, meta=np.array([], dtype=np.float32)
-                               )
+        result = da.map_blocks(
+            np.cumsum,
+            result[..., 0].rechunk((len_t, ndim)), 
+            axis=0, 
+            meta=np.array([], dtype=np.float32)
+        )
 
         return result
     
