@@ -11,7 +11,6 @@ if sys.version_info < (3, 10):
 else:
     from typing import ParamSpec
 import numpy as np
-from numpy.typing import ArrayLike, DTypeLike, _ShapeLike
 from functools import wraps
 
 from . import io
@@ -19,24 +18,30 @@ from .utils import gauss
 from .utils.slicer import *
 from ._types import *
 
-from .axes import ImageAxesError, broadcast, Axes
+from .axes import ImageAxesError, broadcast, Axes, AxesLike, AxesTuple
 from .collections import DataList
 from .arrays.bases import MetaArray
-from .arrays import ImgArray, LazyImgArray
+from .arrays import ImgArray, LazyImgArray, Label
 from ._const import Const
 
 if TYPE_CHECKING:
+    from numpy.typing import ArrayLike, DTypeLike
     from .roi import RoiList
+    # NOTE: "_ShapeLike" is not a public type in numpy.typing.
+    from typing import SupportsIndex, Union
+    ShapeLike = Union[SupportsIndex, Sequence[SupportsIndex]]
 
 __all__ = [
     "array", 
-    "asarray", 
+    "asarray",
+    "aslabel", 
     "aslazy", 
     "zeros", 
     "empty", 
     "ones", 
     "full",
     "arange",
+    "indices",
     "gaussian_kernel", 
     "circular_mask", 
     "imread", 
@@ -62,19 +67,36 @@ shared_docs = \
         Image axes.
     """    
     
-def write_docs(func):
+def _write_docs(func):
     """Add doc for numpy function."""
     func.__doc__ = re.sub(r"{}", shared_docs, func.__doc__)
     return func
 
-@write_docs
+def _normalize_params(
+    axes: AxesLike | None = None,
+    name: str | None = None,
+    like: MetaArray | None = None
+) -> tuple[AxesLike | None, str | None]:
+    """Normalize input parameters for MetaArray construction."""
+    if like is not None:
+        if not isinstance(like, MetaArray):
+            raise TypeError(f"'like' must be a MetaArray, not {type(like)}")
+        name = name or like.name
+        axes = axes or like.axes
+    return axes, name
+    
+
+@_write_docs
 def array(
     arr: ArrayLike,
+    /,
     dtype: DTypeLike = None, 
     *,
+    copy: bool = True,
     name: str = None,
     axes: str = None,
-    copy: bool = True
+    like: MetaArray | None = None,
+    
 ) -> ImgArray:
     """
     make an ImgArray object, like ``np.array(x)``
@@ -83,9 +105,9 @@ def array(
     ----------
     arr : array-like
         Base array.
-    {}
     copy : bool, default is True
         If True, a copy of the original array is made.
+    {}
         
     Returns
     -------
@@ -100,23 +122,29 @@ def array(
         else:
             dtype = arr.dtype
     
-    arr = np.array(arr, dtype=dtype, copy=copy)
+    axes, name = _normalize_params(axes, name, like)
         
+    _arr = np.array(arr, dtype=dtype, copy=copy)
+    
     # Automatically determine axes
     if axes is None:
-        axes = ["", "x", "yx", "tyx", "tzyx", "tzcyx", "ptzcyx"][arr.ndim]
+        if isinstance(arr, MetaArray):
+            axes = arr.axes
+        else:
+            axes = ["", "x", "yx", "tyx", "tzyx", "tzcyx", "ptzcyx"][_arr.ndim]
             
-    self = ImgArray(arr, name=name, axes=axes)
+    self = ImgArray(_arr, name=name, axes=axes)
     
     return self
 
-@write_docs
+@_write_docs
 def asarray(
     arr: ArrayLike,
     dtype: DTypeLike = None,
     *, 
     name: str = None,
-    axes: str = None
+    axes: str = None,
+    like: MetaArray | None = None,
 ) -> ImgArray:
     """
     make an ImgArray object, like ``np.asarray(x)``
@@ -134,16 +162,72 @@ def asarray(
     ImgArray
     
     """
-    return array(arr, dtype=dtype, name=name, axes=axes, copy=False)
+    return array(arr, dtype=dtype, name=name, axes=axes, copy=False, like=like)
 
-@write_docs
+@_write_docs
+def aslabel(
+    arr: ArrayLike,
+    dtype: DTypeLike = None,
+    *, 
+    name: str = None,
+    axes: str = None,
+    like: MetaArray | None = None,
+) -> ImgArray:
+    """
+    Make an Label object.
+    
+    This function helps to create a Label object from an array. Dtype check is performed
+    on array creation.
+    
+    Parameters
+    ----------
+    arr : array-like
+        Base array.
+    {}
+        
+    Returns
+    -------
+    Label
+    
+    """
+    if isinstance(arr, np.ndarray) and dtype is None:
+        if arr.dtype.kind == "u":
+            dtype = arr.dtype
+        elif arr.dtype.kind == "i":
+            if arr.dtype in ("int8", "int16"):
+                dtype = np.uint8
+            elif arr.dtype == "int32":
+                dtype = np.uint16
+            elif arr.dtype == "int64":
+                dtype = np.uint32
+            else:
+                dtype = np.uint64
+        else:
+            raise ValueError(f"Dtype {arr.dtype} is not supported for a Label.")
+    
+    axes, name = _normalize_params(axes, name, like)
+
+    _arr = np.asarray(arr, dtype=dtype)
+        
+    # Automatically determine axes
+    if axes is None:
+        if isinstance(arr, MetaArray):
+            axes = arr.axes
+        else:
+            axes = ["", "x", "yx", "tyx", "tzyx", "tzcyx", "ptzcyx"][_arr.ndim]
+            
+    self = Label(_arr, name=name, axes=axes)
+    return self
+
+@_write_docs
 def aslazy(
     arr: ArrayLike, 
     dtype: DTypeLike = None,
     *, 
     name: str = None,
     axes: str = None,
-    chunks="auto"
+    chunks="auto",
+    like: MetaArray | None = None,
 ) -> LazyImgArray:
     """
     Make an LazyImgArray object from other types of array.
@@ -177,6 +261,8 @@ def aslazy(
         else:
             dtype = arr.dtype
         
+    axes, name = _normalize_params(axes, name, like)
+
     # Automatically determine axes
     if axes is None:
         axes = ["x", "yx", "tyx", "tzyx", "tzcyx", "ptzcyx"][arr.ndim-1]
@@ -191,9 +277,10 @@ def _inject_numpy_function(func: Callable[_P, Any | None]) -> Callable[_P, ImgAr
     npfunc: Callable = getattr(np, func.__name__)
     @wraps(func)
     def _func(*args, **kwargs):
+        like = kwargs.pop("like", None)
         axes = kwargs.pop("axes", None)
         name = kwargs.pop("name", None)
-        return asarray(npfunc(*args, **kwargs), name=name, axes=axes)
+        return asarray(npfunc(*args, **kwargs), name=name, axes=axes, like=like)
     
     _func.__doc__ = (
         f"""
@@ -214,25 +301,62 @@ def _inject_numpy_function(func: Callable[_P, Any | None]) -> Callable[_P, ImgAr
     return _func
 
 @_inject_numpy_function
-def zeros(shape: _ShapeLike, dtype: DTypeLike = np.uint16, *, name: str = None, axes: str = None): ...
+def zeros(shape: ShapeLike, dtype: DTypeLike = np.uint16, *, name: str | None = None, axes: AxesLike | None = None, like: MetaArray | None = None): ...
     
 @_inject_numpy_function
-def empty(shape: _ShapeLike, dtype: DTypeLike = np.uint16, *, name: str = None, axes: str = None): ...
+def empty(shape: ShapeLike, dtype: DTypeLike = np.uint16, *, name: str | None = None, axes: AxesLike | None = None, like: MetaArray | None = None): ...
 
 @_inject_numpy_function
-def ones(shape: _ShapeLike, dtype: DTypeLike = np.uint16, *, name: str = None, axes: str = None): ...
+def ones(shape: ShapeLike, dtype: DTypeLike = np.uint16, *, name: str | None = None, axes: AxesLike | None = None, like: MetaArray | None = None): ...
 
 @_inject_numpy_function
-def full(shape: _ShapeLike, fill_value: Any, dtype: DTypeLike = np.uint16, *, name: str = None, axes: str = None): ...
+def full(shape: ShapeLike, fill_value: Any, dtype: DTypeLike = np.uint16, *, name: str | None = None, axes: AxesLike | None = None, like: MetaArray | None = None): ...
 
 @_inject_numpy_function
 def arange(stop: int, dtype: DTypeLike = ..., like: Any = ...): ...
+    
+def indices(
+    dimensions: ShapeLike,
+    dtype: DTypeLike = np.uint16,
+    *, 
+    name: str | None = None,
+    axes: AxesLike | None = None,
+    like: MetaArray | None = None,
+) -> AxesTuple[ImgArray]:
+    """
+    Copy of ``numpy.indices``.
+    
+    Parameters
+    ----------
+    dimensions : shape-like
+        The shape of the grid.
+    dtype : dtype, optional
+        Data type of the result.
+    name : str, optional
+        Name of the result arrays.
+    axes : AxesLike, optional
+        Axes of the result arrays.
+    like : MetaArray, optional
+        Reference array from which name and axes will be copied.
+
+    Returns
+    -------
+    tuple of ImgArray
+        
+    """
+    out = tuple(
+        asarray(ind, name=name, axes=axes, like=like) for ind in np.indices(dimensions, dtype=dtype)
+    )
+    return out[0].axes.tuple(out)
 
 
 def gaussian_kernel(
-    shape: _ShapeLike, 
+    shape: ShapeLike, 
     sigma: nDFloat = 1.0,
     peak: float = 1.0,
+    *,
+    name: str | None = None,
+    axes: AxesLike | None = None,
 ) -> ImgArray:
     """
     Make an Gaussian kernel or Gaussian image.
@@ -255,15 +379,15 @@ def gaussian_kernel(
         sigma = (sigma,)*len(shape)
     g = gauss.GaussianParticle([(np.array(shape)-1)/2, sigma, peak, 0])
     ker = g.generate(shape)
-    ker = array(ker, name="Gaussian-Kernel")
-    if ker.ndim == 3:
+    ker = array(ker, name=name or "Gaussian-Kernel", axes=axes)
+    if axes is None and ker.ndim == 3:
         ker.axes = "zyx"
     return ker
 
 
 def circular_mask(
     radius: nDFloat, 
-    shape: _ShapeLike,
+    shape: ShapeLike,
     center: str | tuple[float, ...] = "center"
 ) -> ImgArray:
     """
@@ -432,11 +556,12 @@ def imread(
         
     # if key="y=0", ImageAxisError happens here because image loses y-axis. We have to set scale
     # one by one.
-    for k, v in scale.items():
-        if k in self.axes:
-            self.set_scale({k: v})
-            if k in "zyx":
-                self.axes[k].unit = scale_unit[k]
+    if scale is not None:
+        for k, v in scale.items():
+            if k in self.axes:
+                self.set_scale({k: v})
+                if k in "zyx":
+                    self.axes[k].unit = scale_unit[k]
     
     return self.sort_axes().as_img_type(dtype) # arrange in tzcyx-order
 
@@ -742,7 +867,7 @@ def _lazy_imread_glob(path: str, squeeze: bool = False, **kwargs) -> LazyImgArra
     return out
 
 
-def read_meta(path: str) -> dict[str]:
+def read_meta(path: str) -> dict[str, Any]:
     """
     Read the metadata of an image file. 
 
@@ -757,7 +882,7 @@ def read_meta(path: str) -> dict[str]:
         Dictionary of keys {"axes", "scale", "metadata"}        
     """    
     path = str(path)
-    image_data = io.imread_dask(path, chunks="default")
+    image_data = io.imread_dask(path, chunks="auto")
     return {
         "axes": image_data.axes,
         "scale": image_data.scale,
@@ -768,4 +893,4 @@ def roiread(path: str) -> RoiList:
     """Read a Roi.zip file as a RoiList object."""
     from .roi import RoiList
     
-    return RoiList.fromfile(path)
\ No newline at end of file
+    return RoiList.fromfile(path)
