@@ -424,6 +424,7 @@ def _(path: str, img: ImpyArray, lazy: bool = False):
         warnings.warn(
             f"Scale unit was {img.scale_unit}. Could not normalize scale."
         )
+        voxel_size = (1.0, 1.0, 1.0)
     
     if lazy:
         mode = _MRC_MODE[img.dtype]
@@ -467,6 +468,9 @@ def _(path: str, img: ImpyArray, lazy: bool = False):
         f.array("data", z)
     return None
 
+@IO.mark_writer("")
+def _(path: str, img: ImpyArray, lazy: bool = False):
+    raise ValueError(f"Input path {path!r} does not have file extension.")
 
 _MRC_MODE = {
     np.dtype("int8"): 0,
@@ -502,7 +506,10 @@ def _get_ijmeta_from_img(img: "MetaArray", update_lut=True):
     except:
         info = {}
     metadata["Info"] = str(info)
-    metadata["unit"] = img.scale_unit
+    scale_unit = img.scale_unit
+    if scale_unit[0] == "μ":
+        scale_unit = "\\u00B5" + scale_unit[1:]
+    metadata["unit"] = scale_unit
         
     # set axes in tiff metadata
     metadata["axes"] = str(img.axes).upper()
@@ -516,4 +523,3 @@ imread_dask = IO.imread_dask
 imsave = IO.imsave
 mark_reader = IO.mark_reader
 mark_writer = IO.mark_writer
-
